#include "any-client.h"
#include "any-server.h"


static const CORBA::Long _oc_any_seq[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    16, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x616e795f), ACE_NTOHL(0x7365713a), ACE_NTOHL(0x312e3000) /* repository ID = IDL:any_seq:1.0 */,
    8, ACE_NTOHL(0x616e795f), ACE_NTOHL(0x73657100) /* name = any_seq */,
    CORBA::tk_sequence,
    12 /* encapsulation length */,
      TAO_ENCAP_BYTE_ORDER /* byte order */,
      CORBA::tk_any,
      0
};

static CORBA::TypeCode _tc_TAO_tc_any_seq (CORBA::tk_alias, sizeof(_oc_any_seq), (char *) &_oc_any_seq, 0, sizeof(any_seq ));

CORBA::TypeCode_ptr _tc_any_seq = &_tc_TAO_tc_any_seq;


any_seq::any_seq()
  : _maximum(0),
    _length(0),
    _buffer(0),
    _release(0)
{
}

any_seq::any_seq(CORBA::ULong max)
  : _maximum(max), _length(0), _release(1)
{
  this->_buffer = any_seq::allocbuf(this->_maximum);
}

any_seq::any_seq(CORBA::ULong max, CORBA::ULong length, CORBA::Any *buffer, CORBA::Boolean release)
  : _maximum(max),
    _length(length),
    _buffer(buffer),
    _release(release)
{
}

any_seq::any_seq(const any_seq &o)
  : _maximum(o._maximum),
    _length(o._length),
    _release(1)
{
  CORBA::Any  *tmp1 = any_seq::allocbuf(this->_maximum);

  CORBA::Any  * const tmp2 = ACE_reinterpret_cast(CORBA::Any  * ACE_CAST_CONST, o._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  this->_buffer = tmp1;
}

any_seq::~any_seq()
{
  this->_deallocate_buffer();
}

any_seq &any_seq::operator=(const any_seq &rhs)
{
  if( this == &rhs )
    return *this;

  if( this->_release )
  {
  
    if( this->_maximum < rhs._maximum )
    {
      CORBA::Any  *tmp = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);

      any_seq::freebuf(tmp);
      this->_buffer = any_seq::allocbuf(rhs._maximum);
    }

  }
  else
    this->_buffer = any_seq::allocbuf(rhs._maximum);

  this->_maximum = rhs._maximum;
  this->_length = rhs._length;
  this->_release = 1;
  CORBA::Any  *tmp1 = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);
  CORBA::Any  * const tmp2 = ACE_reinterpret_cast(CORBA::Any  * ACE_CAST_CONST, rhs._buffer);

  for(CORBA::ULong i = 0; i < this->_length; i++ )
    tmp1[i] = tmp2[i];

  return *this;
}

CORBA::Any &any_seq::operator[](CORBA::ULong i)
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Any  * tmp = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);
  return tmp[i];
}

const CORBA::Any &any_seq::operator[](CORBA::ULong i) const
{
  ACE_ASSERT(i < this->_maximum);
  CORBA::Any  * const tmp = ACE_reinterpret_cast(CORBA::Any  *ACE_CAST_CONST, this->_buffer);
  return tmp[i];
}

CORBA::Any *any_seq::allocbuf(CORBA::ULong size)
{
  CORBA::Any  *tmp;
  tmp = new CORBA::Any [size];
  return tmp;
}

void any_seq::freebuf(CORBA::Any *buffer)
{
  delete [] buffer;
}

void any_seq::_allocate_buffer(CORBA::ULong length)
{
  CORBA::Any  *tmp = any_seq::allocbuf(length);

  if( this->_buffer != 0 )
  {
    CORBA::ULong i;
    CORBA::Any  *old = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);

    for( i = 0; i < this->_length; i++ )
      tmp[i] = old[i];

    if( this->_release )
      any_seq::freebuf(old);
  }
  this->_buffer = tmp;
}

void any_seq::_deallocate_buffer()
{
  if( this->_buffer == 0 || this->_release == 0 )
    return;

  CORBA::Any  *tmp = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);


  any_seq::freebuf(tmp);
  this->_buffer = 0;
}

CORBA::Boolean any_seq::release() const
{
  return this->_release;
}

CORBA::ULong any_seq::maximum() const
{
  return this->_maximum;
}

CORBA::ULong any_seq::length() const
{
  return this->_length;
}

void any_seq::length(CORBA::ULong length)
{
  if( length > this->_maximum )
  {
    this->_allocate_buffer(length);
    this->_maximum = length;
    this->_release = 1;
  }
  else if (length < this->_length)
  {
    this->_shrink_buffer(length, this->_length);
  }
  this->_length = length;
}

void any_seq::_shrink_buffer(CORBA::ULong , CORBA::ULong )
{
}

CORBA::Any *any_seq::get_buffer(CORBA::Boolean orphan)
{
  CORBA::Any  *result = 0;
  if( orphan == 0 )
  {
    if( this->_buffer == 0 )
    {
      result = any_seq::allocbuf(this->_length);
      this->_buffer = result;
    }
    else
    {
      result = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);
    }
  }
  else
  {
    if( this->_release != 0 )
    {
      result = ACE_reinterpret_cast(CORBA::Any  *, this->_buffer);
      this->_maximum = 0;
      this->_length = 0;
      this->_buffer = 0;
      this->_release = 0;
    }
  }
  return result;
}

const CORBA::Any *any_seq::get_buffer() const
{
  return ACE_const_cast(const CORBA::Any  * ACE_CAST_CONST, this->_buffer);
}

void operator<<=(CORBA::Any &a, const any_seq &o)
{
  any_seq  *_any_val;
  ACE_NEW(_any_val, any_seq  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_any_seq, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, any_seq *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_any_seq, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, any_seq *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_any_seq, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (any_seq  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, any_seq , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_any_seq, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_any_seq, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

any_seq_var::any_seq_var()
  : ptr_(0)
{}

any_seq_var::any_seq_var(any_seq *p)
 : ptr_(p)
{}

any_seq_var::any_seq_var(const any_seq_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new any_seq (*a.ptr_);
  else
    this->ptr_ = 0;
}

any_seq_var::~any_seq_var()
{
  delete this->ptr_;
}

any_seq_var &any_seq_var::operator=(any_seq *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

any_seq_var &any_seq_var::operator=(const any_seq_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new any_seq (*p.ptr_);
  }
  return *this;
}

CORBA::Any &any_seq_var::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Any &any_seq_var::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

any_seq *any_seq_var::operator->()
{
  return this->ptr_;
}

const any_seq *any_seq_var::operator->() const
{
  return this->ptr_;
}

any_seq_var::operator const any_seq &() const
{
  return *this->ptr_;
}

any_seq_var::operator any_seq &()
{
  return *this->ptr_;
}

any_seq_var::operator any_seq &() const
{
  return *this->ptr_;
}

const any_seq &any_seq_var::in() const
{
  return *this->ptr_;
}

any_seq &any_seq_var::inout()
{
  return *this->ptr_;
}

any_seq *&any_seq_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

any_seq *any_seq_var::_retn()
{
  any_seq  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

any_seq *any_seq_var::ptr() const
{
  return this->ptr_;
}

any_seq_out::any_seq_out(any_seq *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

any_seq_out::any_seq_out(any_seq_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

any_seq_out::any_seq_out(const any_seq_out &r)
  : ptr_(ACE_const_cast(any_seq_out &,r).ptr_)
{}

any_seq_out &any_seq_out::operator=(const any_seq_out &r)
{
  this->ptr_ = ACE_const_cast(any_seq_out &,r).ptr_;
  return *this;
}

any_seq_out &any_seq_out::operator=(any_seq *r)
{
  this->ptr_ = r;
  return *this;
}

any_seq_out::operator any_seq *&()
{
  return this->ptr_;
}

any_seq *&any_seq_out::ptr()
{
  return this->ptr_;
}

CORBA::Any &any_seq_out::operator[](CORBA::ULong index)
{
  return this->ptr_->operator[](index);
}

const CORBA::Any &any_seq_out::operator[](CORBA::ULong index) const
{
  return this->ptr_->operator[](index);
}

any_seq *any_seq_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_any_struct[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    19, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x616e795f), ACE_NTOHL(0x73747275), ACE_NTOHL(0x63743a31), ACE_NTOHL(0x2e300000) /* repository ID = IDL:any_struct:1.0 */,
    11, ACE_NTOHL(0x616e795f), ACE_NTOHL(0x73747275), ACE_NTOHL(0x63740000) /* name = any_struct */,
    3 /* member count */,
    7, ACE_NTOHL(0x736c6f74), ACE_NTOHL(0x5f310000) /* name = slot_1 */,
    CORBA::tk_long,
    7, ACE_NTOHL(0x736c6f74), ACE_NTOHL(0x5f320000) /* name = slot_2 */,
    CORBA::tk_any,
    7, ACE_NTOHL(0x736c6f74), ACE_NTOHL(0x5f330000) /* name = slot_3 */,
    CORBA::tk_long
};

static CORBA::TypeCode _tc_TAO_tc_any_struct (CORBA::tk_struct, sizeof(_oc_any_struct), (char *) &_oc_any_struct, 0, sizeof(struct any_struct ));

CORBA::TypeCode_ptr _tc_any_struct = &_tc_TAO_tc_any_struct;


void operator<<=(CORBA::Any &a, const struct any_struct &o)
{
  struct any_struct  *_any_val;
  ACE_NEW(_any_val, struct any_struct  (o));
  if( !_any_val ) return;
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_any_struct, _any_val, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _any_val;
  }
  ACE_ENDTRY;
}

void operator<<=(CORBA::Any &a, struct any_struct *o)
{
  ACE_TRY_NEW_ENV
  {
    a.replace(_tc_any_struct, o, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY {}
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, struct any_struct *&o)
{
  ACE_TRY_NEW_ENV
  {
    CORBA::TypeCode_var type = a.type();
    if(!type->equal(_tc_any_struct, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    if(a.any_owns_data())
    {
      o = (struct any_struct  *)a.value();
      return 1;
    }
    else
    {
      ACE_NEW_RETURN(o, struct any_struct , 0);
      TAO_InputCDR stream (a._tao_get_cdr());
      if(stream.decode(_tc_any_struct, o, 0, ACE_TRY_ENV)
        == CORBA::TypeCode::TRAVERSE_CONTINUE)
      {
        ((CORBA::Any *)&a)->replace(_tc_any_struct, o, 1, ACE_TRY_ENV);
        ACE_TRY_CHECK;
        return 1;
      }
      else
      {
        delete o;
      }
    }
  }
  ACE_CATCHANY
  {
    delete o;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

any_struct_var::any_struct_var()
  : ptr_(0)
{}

any_struct_var::any_struct_var(struct any_struct *p)
 : ptr_(p)
{}

any_struct_var::any_struct_var(const any_struct_var &a)
{
  if( a.ptr_ )
    this->ptr_ = new struct any_struct (*a.ptr_);
  else
    this->ptr_ = 0;
}

any_struct_var::~any_struct_var()
{
  delete this->ptr_;
}

any_struct_var &any_struct_var::operator=(struct any_struct *p)
{
  delete this->ptr_;
  this->ptr_ = p;
  return *this;
}

any_struct_var &any_struct_var::operator=(const any_struct_var &p)
{
  if( this != &p )
  {
    delete this->ptr_;
    this->ptr_ = new struct any_struct (*p.ptr_);
  }
  return *this;
}

struct any_struct *any_struct_var::operator->()
{
  return this->ptr_;
}

const struct any_struct *any_struct_var::operator->() const
{
  return this->ptr_;
}

any_struct_var::operator const struct any_struct &() const
{
  return *this->ptr_;
}

any_struct_var::operator struct any_struct &()
{
  return *this->ptr_;
}

any_struct_var::operator struct any_struct &() const
{
  return *this->ptr_;
}

const struct any_struct &any_struct_var::in() const
{
  return *this->ptr_;
}

struct any_struct &any_struct_var::inout()
{
  return *this->ptr_;
}

struct any_struct *&any_struct_var::out()
{
  delete this->ptr_;
  this->ptr_ = 0;
  return this->ptr_;
}

struct any_struct *any_struct_var::_retn()
{
  struct any_struct  *tmp = this->ptr_;
  this->ptr_ = 0;
  return tmp;
}

struct any_struct *any_struct_var::ptr() const
{
  return this->ptr_;
}

any_struct_out::any_struct_out(struct any_struct *&r)
  : ptr_(r)
{
  this->ptr_ = 0;
}

any_struct_out::any_struct_out(any_struct_var &r)
  : ptr_(r.out())
{
  delete this->ptr_;
  this->ptr_ = 0;
}

any_struct_out::any_struct_out(const any_struct_out &r)
  : ptr_(ACE_const_cast(any_struct_out &,r).ptr_)
{}

any_struct_out &any_struct_out::operator=(const any_struct_out &r)
{
  this->ptr_ = ACE_const_cast(any_struct_out &,r).ptr_;
  return *this;
}

any_struct_out &any_struct_out::operator=(struct any_struct *r)
{
  this->ptr_ = r;
  return *this;
}

any_struct_out::operator struct any_struct *&()
{
  return this->ptr_;
}

struct any_struct *&any_struct_out::ptr()
{
  return this->ptr_;
}

struct any_struct *any_struct_out::operator->()
{
  return this->ptr_;
}

static const CORBA::Long _oc_I[] =
{
    TAO_ENCAP_BYTE_ORDER /* byte order */,
    10, ACE_NTOHL(0x49444c3a), ACE_NTOHL(0x493a312e), ACE_NTOHL(0x30000000) /* repository ID = IDL:I:1.0 */,
    2, ACE_NTOHL(0x49000000) /* name = I */
};

static CORBA::TypeCode _tc_TAO_tc_I (CORBA::tk_objref, sizeof(_oc_I), (char *) &_oc_I, 0, sizeof(I ));

CORBA::TypeCode_ptr _tc_I = &_tc_TAO_tc_I;


#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
  template class TAO_Object_Field_T<I , I_var >;
#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
#  pragma instantiate TAO_Object_Field_T<I , I_var >
#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */


I_ptr  (*_TAO_collocation_I_Stub_Factory_function_pointer)(CORBA::Object_ptr obj) = 0;


I_ptr I::_duplicate(I_ptr obj)
{
  if( !CORBA::is_nil(obj) )
    obj->_incr_refcnt();
  return obj;
}

I_ptr I::_narrow(CORBA::Object_ptr obj, CORBA::Environment &_env)
{
  if (CORBA::is_nil(obj))
    return I::_nil();
  CORBA::Boolean is_a = obj->_is_a ("IDL:I:1.0", _env);
  if (_env.exception() != 0)
    return I::_nil();
  if (is_a == 0)
    return I::_nil();
  return I::_unchecked_narrow(obj, _env);
}

I_ptr I::_unchecked_narrow(CORBA::Object_ptr _obj, CORBA::Environment &)
{
  if( CORBA::is_nil(_obj) )
    return I::_nil();
  TAO_Stub *stub = _obj->_stubobj();
  stub->_incr_refcnt();
  if (_obj->_is_collocated () && _TAO_collocation_I_Stub_Factory_function_pointer != 0)
    {
      I_ptr  retv = _TAO_collocation_I_Stub_Factory_function_pointer(_obj);
      if (retv != 0)
        return retv;
    }
  return new I (stub);
}

I_ptr I::_nil()
{
  return (I_ptr )NULL;
}

CORBA::Boolean I::_is_a(const CORBA::Char *_type_id, CORBA::Environment &_env)
{
  if( (!ACE_OS::strcmp((char *)_type_id, "IDL:I:1.0")) ||
      (!ACE_OS::strcmp((char *)_type_id, CORBA::_tc_Object->id(_env))) )
    return 1;
  else
    return this->CORBA_Object::_is_a(_type_id, _env);
}

const char *I::_interface_repository_id() const
{
  return "IDL:I:1.0";
}

I::I()
{}

I::~I()
{}

void operator<<=(CORBA::Any &a, I_ptr o)
{
  CORBA::Object_ptr *_tao_obj_ptr = 0;
  ACE_TRY_NEW_ENV
  {
    ACE_NEW(_tao_obj_ptr, CORBA::Object_ptr);
    *_tao_obj_ptr = I::_duplicate(o);
    a.replace (_tc_I, _tao_obj_ptr, 1, ACE_TRY_ENV);
    ACE_TRY_CHECK;
  }
  ACE_CATCHANY
  {
    delete _tao_obj_ptr;
  }
  ACE_ENDTRY;
}

CORBA::Boolean operator>>=(const CORBA::Any &a, I_ptr &o)
{
  CORBA::Object_ptr *tmp = 0;
  ACE_TRY_NEW_ENV
  {
    o = I::_nil();
    CORBA::TypeCode_var type = a.type();
    if (!type->equal (_tc_I, ACE_TRY_ENV)) return 0;
    ACE_TRY_CHECK;
    TAO_InputCDR stream (a._tao_get_cdr());
    CORBA::Object_var _tao_obj_var;
    ACE_NEW_RETURN (tmp, CORBA::Object_ptr, 0);
    if (stream.decode(_tc_I, &_tao_obj_var.out(), 0, ACE_TRY_ENV)
       == CORBA::TypeCode::TRAVERSE_CONTINUE)
    {
      o = I::_narrow(_tao_obj_var.in(), ACE_TRY_ENV);
      ACE_TRY_CHECK;
      *tmp = (CORBA::Object_ptr) o;
      ((CORBA::Any *)&a)->replace(_tc_I, tmp, 1, ACE_TRY_ENV);
      ACE_TRY_CHECK;
      return 1;
    }
  }
  ACE_CATCHANY
  {
    delete tmp;
    return 0;
  }
  ACE_ENDTRY;
  return 0;
}

I::I(TAO_Stub *objref, TAO_ServantBase *_tao_servant, CORBA::Boolean _tao_collocated)
  : CORBA_Object(objref, _tao_servant, _tao_collocated)
{}

I_var::I_var()
  : ptr_(I::_nil())
{}

I_var::I_var(I_ptr p)
  : ptr_(p)
{}

I_var::I_var(const I_var &a)
  : ptr_(I::_duplicate(a.ptr()))
{}

I_var::~I_var()
{
  CORBA::release(this->ptr_);
}

I_var &I_var::operator=(I_ptr p)
{
  CORBA::release(this->ptr_);
  this->ptr_ = p;
  return *this;
}

I_var &I_var::operator=(const I_var &p)
{
  if( this != &p )
  {
    CORBA::release(this->ptr_);
    this->ptr_ = I::_duplicate(p.ptr());
  }
  return *this;
}

I_ptr I_var::operator->() const
{
  return this->ptr_;
}

I_var::operator const I_ptr &() const
{
  return this->ptr_;
}

I_var::operator I_ptr &()
{
  return this->ptr_;
}

I_ptr I_var::in() const
{
  return this->ptr_;
}

I_ptr &I_var::inout()
{
  return this->ptr_;
}

I_ptr &I_var::out()
{
  CORBA::release(this->ptr_);
  this->ptr_ = I::_nil();
  return this->ptr_;
}

I_ptr I_var::_retn()
{
  I_ptr  val = this->ptr_;
  this->ptr_ = I::_nil();
  return val;
}

I_ptr I_var::ptr() const
{
  return this->ptr_;
}

I_out::I_out(I_ptr &r)
  : ptr_(r)
{
  this->ptr_ = I::_nil();
}

I_out::I_out(I_var &r)
  : ptr_(r.out())
{
  CORBA::release(this->ptr_);
  this->ptr_ = I::_nil();
}

I_out::I_out(const I_out &r)
  : ptr_(ACE_const_cast(I_out &,r).ptr_)
{}

I_out &I_out::operator=(const I_out &r)
{
  this->ptr_ = ACE_const_cast(I_out &,r).ptr_;
  return *this;
}

I_out &I_out::operator=(const I_var &r)
{
  this->ptr_ = I::_duplicate(r.ptr());
  return *this;
}

I_out &I_out::operator=(I_ptr r)
{
  this->ptr_ = r;
  return *this;
}

I_out::operator I_ptr &()
{
  return this->ptr_;
}

I_ptr &I_out::ptr()
{
  return this->ptr_;
}

I_ptr I_out::operator->()
{
  return this->ptr_;
}
CORBA::Any *I::op_any(/* I *this, */ const CORBA::Any &a, CORBA::Any &b, CORBA::Any_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  CORBA::Any *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort1);
    }




    {
      flick_iiopxx_encode_new_glob(16, _flick_abort1);
      flick_iiopxx_encode_new_chunk(16);
      flick_cdr_encode_unsigned32(0, 7, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '_', flick_char8_t );
      flick_cdr_encode_char8(7, 'a', flick_char8_t );
      flick_cdr_encode_char8(8, 'n', flick_char8_t );
      flick_cdr_encode_char8(9, 'y', flick_char8_t );
      flick_cdr_encode_char8(10, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(12, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_iiopxx_encode_end_chunk(16);
      flick_iiopxx_encode_end_glob(16);
      flick_cdr_encode_type_tag_and_value(iiopxx, a, _flick_label2, _flick_abort1);
      flick_cdr_encode_type_tag_and_value(iiopxx, b, _flick_label3, _flick_abort1);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort1);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t1_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t1_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t1_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new CORBA::Any ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort14);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, *_return, _flick_label13, _flick_abort14);
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, b, _flick_label14, _flick_abort14);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new CORBA::Any ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort14);
                c = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, *c, _flick_label15, _flick_abort14);
              break;
              {
              _flick_abort14:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort15);
              break;
              {
              _flick_abort15:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort16);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort16:
                goto _flick_abort1;
              }
            }
          }
      }

    else
      {
        int _t0_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(4);
        flick_iiopxx_check_span(4, _flick_abort1);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t0_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t0_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new CORBA::Any ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort7);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_decode_end_glob(4);
              flick_cdr_decode_type_tag_and_value(iiopxx, *_return, _flick_label7, _flick_abort7);
              flick_cdr_decode_type_tag_and_value(iiopxx, b, _flick_label8, _flick_abort7);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new CORBA::Any ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort7);
                c = _t_alloc_ptr;
              }
              flick_cdr_decode_type_tag_and_value(iiopxx, *c, _flick_label9, _flick_abort7);
              break;
              {
              _flick_abort7:
                goto _flick_abort1;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(4);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort8);
              break;
              {
              _flick_abort8:
                goto _flick_abort1;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort9);
              flick_iiopxx_decode_end_glob(4);
              break;
              {
              _flick_abort9:
                goto _flick_abort1;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort1);
  }
  return _return;
  {
  _flick_abort1:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort0);
  _flick_abort0:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

any_seq *I::op_any_seq(/* I *this, */ const any_seq &a, any_seq &b, any_seq_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  any_seq *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort18);
    }




    {
      CORBA::ULong _t4_array_iter;
      CORBA::ULong _t5_array_iter;

      flick_iiopxx_encode_new_glob(24, _flick_abort18);
      flick_iiopxx_encode_new_chunk(24);
      flick_cdr_encode_unsigned32(0, 11, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '_', flick_char8_t );
      flick_cdr_encode_char8(7, 'a', flick_char8_t );
      flick_cdr_encode_char8(8, 'n', flick_char8_t );
      flick_cdr_encode_char8(9, 'y', flick_char8_t );
      flick_cdr_encode_char8(10, '_', flick_char8_t );
      flick_cdr_encode_char8(11, 's', flick_char8_t );
      flick_cdr_encode_char8(12, 'e', flick_char8_t );
      flick_cdr_encode_char8(13, 'q', flick_char8_t );
      flick_cdr_encode_char8(14, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(16, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_unsigned32(20, a._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(24);
      flick_iiopxx_encode_end_glob(24);
      for (_t4_array_iter = 0; _t4_array_iter < a._length; _t4_array_iter++)
        {
          flick_cdr_encode_type_tag_and_value(iiopxx, a._buffer[_t4_array_iter], _flick_label30, _flick_abort33);
          continue;
          {
          _flick_abort33:
            goto _flick_abort18;
          }
        }
      flick_iiopxx_encode_new_glob(7, _flick_abort18);
      flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
      flick_cdr_encode_unsigned32(0, b._length, CORBA::ULong );
      flick_iiopxx_encode_end_chunk(4);
      flick_iiopxx_encode_end_glob(7);
      for (_t5_array_iter = 0; _t5_array_iter < b._length; _t5_array_iter++)
        {
          flick_cdr_encode_type_tag_and_value(iiopxx, b._buffer[_t5_array_iter], _flick_label35, _flick_abort38);
          continue;
          {
          _flick_abort38:
            goto _flick_abort18;
          }
        }
      if (b._release)
        delete [] b._buffer;
      b._maximum = 0;
      b._release = 0;
      b._buffer = (CORBA::Any *)0;
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort18);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t13_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t13_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t13_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t17_array_iter;
              CORBA::ULong _t18_array_iter;
              CORBA::ULong _t19_array_iter;

              /* Begin decode phase on parameters */
              {
                any_seq *_t_alloc_ptr;

                _t_alloc_ptr = (any_seq *)new any_seq ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort96);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t17_array_iter = 0; _t17_array_iter < _return->_length; _t17_array_iter++)
                {
                  flick_cdr_swap_decode_type_tag_and_value(iiopxx, _return->_buffer[_t17_array_iter], _flick_label85, _flick_abort100);
                  continue;
                  {
                  _flick_abort100:
                    goto _flick_abort96;
                  }
                }
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort96);
              flick_cdr_swap_decode_unsigned32(0, b._length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [b._length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                b._buffer = _t_alloc_ptr;
                b._maximum = b._length;
                b._release = 1;
              }
              for (_t18_array_iter = 0; _t18_array_iter < b._length; _t18_array_iter++)
                {
                  flick_cdr_swap_decode_type_tag_and_value(iiopxx, b._buffer[_t18_array_iter], _flick_label90, _flick_abort105);
                  continue;
                  {
                  _flick_abort105:
                    goto _flick_abort96;
                  }
                }
              {
                any_seq *_t_alloc_ptr;

                _t_alloc_ptr = (any_seq *)new any_seq ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                c = _t_alloc_ptr;
              }
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort96);
              flick_cdr_swap_decode_unsigned32(0, c->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [c->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort96);
                c->_buffer = _t_alloc_ptr;
                c->_maximum = c->_length;
                c->_release = 1;
              }
              for (_t19_array_iter = 0; _t19_array_iter < c->_length; _t19_array_iter++)
                {
                  flick_cdr_swap_decode_type_tag_and_value(iiopxx, c->_buffer[_t19_array_iter], _flick_label95, _flick_abort110);
                  continue;
                  {
                  _flick_abort110:
                    goto _flick_abort96;
                  }
                }
              break;
              {
              _flick_abort96:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort112);
              break;
              {
              _flick_abort112:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort113);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort113:
                goto _flick_abort18;
              }
            }
          }
      }

    else
      {
        int _t6_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort18);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t6_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t6_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              CORBA::ULong _t10_array_iter;
              CORBA::ULong _t11_array_iter;
              CORBA::ULong _t12_array_iter;

              /* Begin decode phase on parameters */
              {
                any_seq *_t_alloc_ptr;

                _t_alloc_ptr = (any_seq *)new any_seq ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort59);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort59);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_unsigned32(0, _return->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [_return->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort59);
                _return->_buffer = _t_alloc_ptr;
                _return->_maximum = _return->_length;
                _return->_release = 1;
              }
              for (_t10_array_iter = 0; _t10_array_iter < _return->_length; _t10_array_iter++)
                {
                  flick_cdr_decode_type_tag_and_value(iiopxx, _return->_buffer[_t10_array_iter], _flick_label55, _flick_abort63);
                  continue;
                  {
                  _flick_abort63:
                    goto _flick_abort59;
                  }
                }
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort59);
              flick_cdr_decode_unsigned32(0, b._length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [b._length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort59);
                b._buffer = _t_alloc_ptr;
                b._maximum = b._length;
                b._release = 1;
              }
              for (_t11_array_iter = 0; _t11_array_iter < b._length; _t11_array_iter++)
                {
                  flick_cdr_decode_type_tag_and_value(iiopxx, b._buffer[_t11_array_iter], _flick_label60, _flick_abort68);
                  continue;
                  {
                  _flick_abort68:
                    goto _flick_abort59;
                  }
                }
              {
                any_seq *_t_alloc_ptr;

                _t_alloc_ptr = (any_seq *)new any_seq ;
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort59);
                c = _t_alloc_ptr;
              }
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort59);
              flick_cdr_decode_unsigned32(0, c->_length, CORBA::ULong );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              {
                CORBA::Any *_t_alloc_ptr;

                _t_alloc_ptr = (CORBA::Any *)new (CORBA::Any [c->_length]);
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort59);
                c->_buffer = _t_alloc_ptr;
                c->_maximum = c->_length;
                c->_release = 1;
              }
              for (_t12_array_iter = 0; _t12_array_iter < c->_length; _t12_array_iter++)
                {
                  flick_cdr_decode_type_tag_and_value(iiopxx, c->_buffer[_t12_array_iter], _flick_label65, _flick_abort73);
                  continue;
                  {
                  _flick_abort73:
                    goto _flick_abort59;
                  }
                }
              break;
              {
              _flick_abort59:
                goto _flick_abort18;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort75);
              break;
              {
              _flick_abort75:
                goto _flick_abort18;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort76);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort76:
                goto _flick_abort18;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort18);
  }
  return _return;
  {
  _flick_abort18:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort17);
  _flick_abort17:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

struct any_struct *I::op_any_struct(/* I *this, */ const struct any_struct &a, struct any_struct &b, any_struct_out c, CORBA::Environment &_ev)
{
  FLICK_BUFFER _stream_storage;
  FLICK_BUFFER *_stream = &_stream_storage;



  TAO_Stub *_istub = this->_stubobj();
  TAO_ORB_Core *_orb_core = TAO_ORB_Core_instance();

  struct any_struct *_return;


  _return = 0;

  if(_istub)
  {
    char _default_buffer[ACE_CDR::DEFAULT_BUFSIZE];
    TAO_OutputCDR _out_cdr(_default_buffer,
                           ACE_CDR::DEFAULT_BUFSIZE,
                           TAO_ENCAP_BYTE_ORDER,
                           _orb_core->output_cdr_buffer_allocator(),
                           _orb_core->output_cdr_dblock_allocator());
    TAO_InputCDR *_in_cdr;
    TAO_Connector_Registry *_conn_reg = _orb_core->connector_registry();
    TAO_Transport *_transport = 0;
    TAO_Profile *_tp = 0;
    CORBA::ULong _my_request_id = 0;
    ACE_Time_Value *_max_wait_time = 0;
    TAO_Synch_Reply_Dispatcher _rd(_orb_core);



    ACE_Countdown_Time _countdown(_max_wait_time);
    for (;;) {
      _tp = _istub->profile_in_use();
      if (_transport)
        _transport->idle();
      _countdown.update();
      int _result = _conn_reg->connect (_tp, _transport);
      _countdown.update();
      if (_result == 0)
        break;
      if (errno == ETIME)
        {
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
        }
      if (_istub->next_profile_retry() == 0)
        flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
    }
    _my_request_id = _transport->request_id();
    _countdown.update();
    flick_iiopxx_client_start_encode();
    {
      _stub_state.state = FLICK_STATE_PROLOGUE;
      _stub_state.state = FLICK_STATE_MARSHAL;
      flick_iiopxx_client_encode_target(this, 0, cdr, _flick_abort115);
    }




    {
      flick_iiopxx_encode_new_glob(28, _flick_abort115);
      flick_iiopxx_encode_new_chunk(28);
      flick_cdr_encode_unsigned32(0, 14, flick_unsigned32_t );
      flick_cdr_encode_char8(4, 'o', flick_char8_t );
      flick_cdr_encode_char8(5, 'p', flick_char8_t );
      flick_cdr_encode_char8(6, '_', flick_char8_t );
      flick_cdr_encode_char8(7, 'a', flick_char8_t );
      flick_cdr_encode_char8(8, 'n', flick_char8_t );
      flick_cdr_encode_char8(9, 'y', flick_char8_t );
      flick_cdr_encode_char8(10, '_', flick_char8_t );
      flick_cdr_encode_char8(11, 's', flick_char8_t );
      flick_cdr_encode_char8(12, 't', flick_char8_t );
      flick_cdr_encode_char8(13, 'r', flick_char8_t );
      flick_cdr_encode_char8(14, 'u', flick_char8_t );
      flick_cdr_encode_char8(15, 'c', flick_char8_t );
      flick_cdr_encode_char8(16, 't', flick_char8_t );
      flick_cdr_encode_char8(17, 0, flick_char8_t );
      /* Encode the requesting `Principal' pseudo object (client ID). */
      flick_cdr_encode_unsigned32(20, (unsigned int) 0, unsigned int );
      /* Begin encode phase on parameters */
      flick_cdr_encode_signed32(24, a.slot_1, CORBA::Long );
      flick_iiopxx_encode_end_chunk(28);
      flick_iiopxx_encode_end_glob(28);
      flick_cdr_encode_type_tag_and_value(iiopxx, a.slot_2, _flick_label98, _flick_abort115);
      flick_iiopxx_encode_new_glob(11, _flick_abort115);
      flick_iiopxx_encode_new_chunk_align(8, 2, 0, 0);
      flick_cdr_encode_signed32(0, a.slot_3, CORBA::Long );
      flick_cdr_encode_signed32(4, b.slot_1, CORBA::Long );
      flick_iiopxx_encode_end_chunk(8);
      flick_iiopxx_encode_end_glob(11);
      flick_cdr_encode_type_tag_and_value(iiopxx, b.slot_2, _flick_label99, _flick_abort115);
      flick_iiopxx_encode_new_glob(7, _flick_abort115);
      flick_iiopxx_encode_new_chunk_align(4, 2, 0, 0);
      flick_cdr_encode_signed32(0, b.slot_3, CORBA::Long );
      flick_iiopxx_encode_end_chunk(4);
      flick_iiopxx_encode_end_glob(7);
    }




    flick_iiopxx_client_end_encode();
    _stub_state.state = FLICK_STATE_SEND;

    flick_iiopxx_client_set_response_expected(1);
    
    if( _transport->bind_reply_dispatcher (_my_request_id, &_rd) == -1 ) {
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
    }
    _countdown.update();
    if( _transport->send_request(_orb_core, _out_cdr,
                                 1, _max_wait_time) == -1 ) {
      _countdown.update();
      _transport->close_connection();
      _transport = 0;
      _tp->reset_hint();
      flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
    } else {
      _countdown.update();
      _istub->set_valid_profile();
      _stub_state.state = FLICK_STATE_RECEIVE;
      int _reply_error = _transport->wait_for_reply(_max_wait_time);
      if (_reply_error == -1)
        {
          if (errno == ETIME)
            flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
          flick_stub_error(FLICK_ERROR_COMMUNICATION, _flick_abort115);
        }
      _in_cdr = &_rd.reply_cdr();
    }
    flick_iiopxx_client_start_decode();



    if(_in_cdr->do_byte_swap())
      {
        int _t21_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort115);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_swap_decode_signed32(0, _t21_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t21_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                struct any_struct *_t_alloc_ptr;

                _t_alloc_ptr = (struct any_struct *)new (struct any_struct );
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort128);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort128);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_swap_decode_signed32(0, _return->slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, _return->slot_2, _flick_label109, _flick_abort128);
              flick_iiopxx_decode_new_glob(11);
              flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
              flick_iiopxx_check_span(8, _flick_abort128);
              flick_cdr_swap_decode_signed32(0, _return->slot_3, CORBA::Long );
              flick_cdr_swap_decode_signed32(4, b.slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(8);
              flick_iiopxx_decode_end_glob(11);
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, b.slot_2, _flick_label110, _flick_abort128);
              flick_iiopxx_decode_new_glob(11);
              flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
              flick_iiopxx_check_span(8, _flick_abort128);
              flick_cdr_swap_decode_signed32(0, b.slot_3, CORBA::Long );
              {
                struct any_struct *_t_alloc_ptr;

                _t_alloc_ptr = (struct any_struct *)new (struct any_struct );
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort128);
                c = _t_alloc_ptr;
              }
              flick_cdr_swap_decode_signed32(4, c->slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(8);
              flick_iiopxx_decode_end_glob(11);
              flick_cdr_swap_decode_type_tag_and_value(iiopxx, c->slot_2, _flick_label111, _flick_abort128);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort128);
              flick_cdr_swap_decode_signed32(0, c->slot_3, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort128:
                goto _flick_abort115;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr_swap, iiopxx, _flick_abort129);
              break;
              {
              _flick_abort129:
                goto _flick_abort115;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort130);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort130:
                goto _flick_abort115;
              }
            }
          }
      }

    else
      {
        int _t20_temp_major;

        _stub_state.state = FLICK_STATE_UNMARSHAL;
        flick_iiopxx_decode_new_glob(8);
        flick_iiopxx_check_span(4, _flick_abort115);
        flick_iiopxx_decode_new_chunk(4);
        flick_cdr_decode_signed32(0, _t20_temp_major, int );
        flick_iiopxx_decode_end_chunk(4);
        switch (_t20_temp_major)
          {
          case CORBA::NO_EXCEPTION:
            {
              /* Begin decode phase on parameters */
              {
                struct any_struct *_t_alloc_ptr;

                _t_alloc_ptr = (struct any_struct *)new (struct any_struct );
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort121);
                _return = _t_alloc_ptr;
              }
              flick_iiopxx_check_span(4, _flick_abort121);
              flick_iiopxx_decode_new_chunk(4);
              flick_cdr_decode_signed32(0, _return->slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(8);
              flick_cdr_decode_type_tag_and_value(iiopxx, _return->slot_2, _flick_label103, _flick_abort121);
              flick_iiopxx_decode_new_glob(11);
              flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
              flick_iiopxx_check_span(8, _flick_abort121);
              flick_cdr_decode_signed32(0, _return->slot_3, CORBA::Long );
              flick_cdr_decode_signed32(4, b.slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(8);
              flick_iiopxx_decode_end_glob(11);
              flick_cdr_decode_type_tag_and_value(iiopxx, b.slot_2, _flick_label104, _flick_abort121);
              flick_iiopxx_decode_new_glob(11);
              flick_iiopxx_decode_new_chunk_align(8, 2, 0, 0);
              flick_iiopxx_check_span(8, _flick_abort121);
              flick_cdr_decode_signed32(0, b.slot_3, CORBA::Long );
              {
                struct any_struct *_t_alloc_ptr;

                _t_alloc_ptr = (struct any_struct *)new (struct any_struct );
                if (!_t_alloc_ptr)
                  flick_stub_error(FLICK_ERROR_NO_MEMORY, _flick_abort121);
                c = _t_alloc_ptr;
              }
              flick_cdr_decode_signed32(4, c->slot_1, CORBA::Long );
              flick_iiopxx_decode_end_chunk(8);
              flick_iiopxx_decode_end_glob(11);
              flick_cdr_decode_type_tag_and_value(iiopxx, c->slot_2, _flick_label105, _flick_abort121);
              flick_iiopxx_decode_new_glob(7);
              flick_iiopxx_decode_new_chunk_align(4, 2, 0, 0);
              flick_iiopxx_check_span(4, _flick_abort121);
              flick_cdr_decode_signed32(0, c->slot_3, CORBA::Long );
              flick_iiopxx_decode_end_chunk(4);
              flick_iiopxx_decode_end_glob(7);
              break;
              {
              _flick_abort121:
                goto _flick_abort115;
              }
            }
          case CORBA::SYSTEM_EXCEPTION:
            {
              flick_iiopxx_decode_end_glob(8);
              flick_corbaxx_decode_system_exception(_ev, cdr, iiopxx, _flick_abort122);
              break;
              {
              _flick_abort122:
                goto _flick_abort115;
              }
            }
          default:
            {
              flick_stub_error(FLICK_ERROR_VIRTUAL_UNION, _flick_abort123);
              flick_iiopxx_decode_end_glob(8);
              break;
              {
              _flick_abort123:
                goto _flick_abort115;
              }
            }
          }
      }






    flick_iiopxx_client_end_decode();
    if (_transport)
      _transport->idle_after_reply();

  } else {
    flick_stub_error(FLICK_ERROR_INVALID_TARGET, _flick_abort115);
  }
  return _return;
  {
  _flick_abort115:
    flick_corbaxx_client_error(cdr, iiopxx, _flick_abort114);
  _flick_abort114:
    goto _flick_reaper;
  }

_flick_reaper:
  return _return;

}

